function dy = Pei_Ying_Lin_2007_ode1(t,y,k)
%==========================================================================
%Stoichiometric parameter values
%==========================================================================
%Parameter Value Unit
%..........................................................................
Yxs = 0.229;%mol mol^-1
fHAc = 0.464;% mol mol^-1
fHBu = 0.83;% mol mol^-1
fHEt = 0.0;% mol mol^-1
fH2 = 3.66;% mol mol^-1
%...........................
%==========================================================================
%Physicochemical parameter values
%==========================================================================
%Parameter Value Unit
%..........................................................................
R = 0.083145;%bar l mol^-1 K^-1
T = 298.15;%k
P = 1;%bar
%..........................................................................
K_a_bu = 10^-4.82; %M
K_a_ac = 10^-4.76; %M
k_A_B_bu = 1e10; %M^-1 d^-1
k_A_B_ac = 1e10; %M^-1 d^-1
K_w = 1e-14; %M
%..........................................................................
%==========================================================================
%Physical parameter values
%==========================================================================
%Parameter Value Unit
%...........................................
V = 0.08;%l
Sca = 0.04;%'mol/l h^-1
San = 0.02;%'mol/l h^-1
%...........................................
%==========================================================================
%Biochemical parameter values Comment
%==========================================================================
%Parameter Value Unit
%...........................................
pHLL = 4;   
pHUL = 5.5;
%...........................................
%==========================================================================
%Initial Conditions
%==========================================================================
%...........................................
SGli = y(1); 
SHAc = y(2); 
SHBu = y(3); 
SHEt = y(4); 
X1   = y(5); 
SH2  = y(6); 
SHAcm= y(7); 
SHBum= y(8); 
%..................................................
%==========================================================================
%Biochemical parameter values Comment
%==========================================================================
%Parameter Value Unit
%...........................................
%qGmax = 1.03;% mol mol^-1 h^-1
%ks1 = 0.0026;%'mol/l h^-1 
%...........................................
%==========================================================================
%calculation of potential Sh
%==========================================================================
%...........................................
Theta = Sca + - SHAcm - SHBum - San; % %added S_ca to orginal equation
Sh = -Theta/2 + sqrt(Theta^2 + 4*K_w)/2;
if(Sh <= 0)
Sh = 1e-12; 
end
rho_A_1 = k_A_B_ac*(SHAcm*(K_a_ac+Sh)-K_a_ac*SHAc);
rho_A_2 = k_A_B_bu*(SHBum*(K_a_bu+Sh)-K_a_bu*SHBu); 
pH = -log10(Sh);
%...........................................
%==========================================================================
%Process inhibition
%==========================================================================
if (pH < pHUL)
IpH = (1+2*10^(0.5*(pHLL-pHUL)))/(1+10^(pH-pHUL)+10^(pHLL-pH));
else
IpH = 1;
end
%==========================================================================
%Biochemical process rates
%==========================================================================
dy(1)=             -k(1)*(SGli/(k(2)+SGli))*X1*IpH;
dy(2)= (1-Yxs)*fHAc*k(1)*(SGli/(k(2)+SGli))*X1*IpH;
dy(3)= (1-Yxs)*fHBu*k(1)*(SGli/(k(2)+SGli))*X1*IpH;
dy(4)= (1-Yxs)*fHEt*k(1)*(SGli/(k(2)+SGli))*X1*IpH;
dy(5)=          Yxs*k(1)*(SGli/(k(2)+SGli))*X1*IpH;
dy(6)=  (1-Yxs)*fH2*k(1)*(SGli/(k(2)+SGli))*X1*IpH;
dy(7)= -rho_A_1;
dy(8)= -rho_A_2;
%..........................................................................
dy = [dy(1);dy(2);dy(3);dy(4);dy(5);dy(6);dy(7);dy(8)];

